==> onboarding-springboot-0.13.1-sources.jar: org/kie/kogito/examples/onboarding/SetupHRModel.java <==
package org.kie.kogito.examples.onboarding;

import java.util.Map;
import java.util.HashMap;

public class SetupHRModel implements org.kie.kogito.Model {

    private String id;

    public void setId(String id) {
        this.id = id;
    }

    public String getId() {
        return this.id;
    }

    @Override
    public Map<String, Object> toMap() {
        Map<String, Object> params = new HashMap();
        params.put("manager", this.manager);
        params.put("employee", this.employee);
        params.put("department", this.department);
        return params;
    }

    @Override
    public void fromMap(Map<String, Object> params) {
        fromMap(null, params);
    }

    public void fromMap(String id, Map<String, Object> params) {
        this.id = id;
        this.manager = (java.lang.String) params.get("manager");
        this.employee = (org.kie.kogito.examples.onboarding.Employee) params.get("employee");
        this.department = (java.lang.String) params.get("department");
    }

    @org.kie.internal.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "manager")
    @javax.validation.Valid()
    private java.lang.String manager;

    public java.lang.String getManager() {
        return manager;
    }

    public void setManager(java.lang.String manager) {
        this.manager = manager;
    }

    @org.kie.internal.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "employee")
    @javax.validation.Valid()
    private org.kie.kogito.examples.onboarding.Employee employee;

    public org.kie.kogito.examples.onboarding.Employee getEmployee() {
        return employee;
    }

    public void setEmployee(org.kie.kogito.examples.onboarding.Employee employee) {
        this.employee = employee;
    }

    @org.kie.internal.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "department")
    @javax.validation.Valid()
    private java.lang.String department;

    public java.lang.String getDepartment() {
        return department;
    }

    public void setDepartment(java.lang.String department) {
        this.department = department;
    }
}

==> onboarding-springboot-0.14.0-sources.jar: org/kie/kogito/examples/onboarding/SetupHRModel.java <==
package org.kie.kogito.examples.onboarding;

import java.util.Map;
import java.util.HashMap;

public class SetupHRModel implements org.kie.kogito.Model {

    private String id;

    public void setId(String id) {
        this.id = id;
    }

    public String getId() {
        return this.id;
    }

    @Override
    public Map<String, Object> toMap() {
        Map<String, Object> params = new HashMap();
        params.put("manager", this.manager);
        params.put("employee", this.employee);
        params.put("department", this.department);
        return params;
    }

    @Override
    public void fromMap(Map<String, Object> params) {
        fromMap(null, params);
    }

    public void fromMap(String id, Map<String, Object> params) {
        this.id = id;
        this.manager = (java.lang.String) params.get("manager");
        this.employee = (org.kie.kogito.examples.onboarding.Employee) params.get("employee");
        this.department = (java.lang.String) params.get("department");
    }

    @org.kie.internal.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "manager")
    @javax.validation.Valid()
    private java.lang.String manager;

    public java.lang.String getManager() {
        return manager;
    }

    public void setManager(java.lang.String manager) {
        this.manager = manager;
    }

    @org.kie.internal.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "employee")
    @javax.validation.Valid()
    private org.kie.kogito.examples.onboarding.Employee employee;

    public org.kie.kogito.examples.onboarding.Employee getEmployee() {
        return employee;
    }

    public void setEmployee(org.kie.kogito.examples.onboarding.Employee employee) {
        this.employee = employee;
    }

    @org.kie.internal.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "department")
    @javax.validation.Valid()
    private java.lang.String department;

    public java.lang.String getDepartment() {
        return department;
    }

    public void setDepartment(java.lang.String department) {
        this.department = department;
    }

    public SetupHRModelOutput toOutput() {
        SetupHRModelOutput result = new SetupHRModelOutput();
        result.setId(getId());
        result.setManager(getManager());
        result.setEmployee(getEmployee());
        result.setDepartment(getDepartment());
        return result;
    }
}
